Structs
- A mutable memory location with dynamically checked borrow rules
Traits
- A data structure that can be deserialized from any data format supported by Serde.
- Parse command-line arguments into
Self. - A data structure that can be serialized into any data format supported by Serde.
Derive Macros
- Generates the
Parserimplementation.